Enums
=====


Sequence Type
-------------

.. autoclass:: zhinst.toolkit.SequenceType
    :show-inheritance:
    :members:
    :undoc-members:

Trigger Mode
------------

.. autoclass:: zhinst.toolkit.TriggerMode
    :show-inheritance:
    :members:
    :undoc-members:

Alignment
---------

.. autoclass:: zhinst.toolkit.Alignment
    :show-inheritance:
    :members:
    :undoc-members:
